@@ -24,6 +24,7 @@ from dungeonsheets import (
 from dungeonsheets.content_registry import find_content
 from dungeonsheets.weapons import Weapon
 from dungeonsheets.content import Creature
+from dungeonsheets.dice import combine_dice
 
 
 dice_re = re.compile(r"(\d+)d(\d+)")
@@ -72,8 +73,8 @@ multiclass_spellslots_by_level = {
 
 class Character(Creature):
     """A generic player character."""
-
     # Character-specific
+    name = "Unknown Hero"
     player_name = ""
     xp = 0
     # Extra hit points info, for characters only
@@ -712,10 +713,7 @@ class Character(Creature):
     @property
     def magic_items_text(self):
         s = ", ".join(
-            [
-                f.name + ("**" if f.needs_implementation else "")
-                for f in sorted(self.magic_items, key=(lambda x: x.name))
-            ]
+            [f.name for f in sorted(self.magic_items, key=(lambda x: x.name))]
         )
         if s:
             s += ", "
@@ -789,9 +787,11 @@ class Character(Creature):
     @property
     def hit_dice(self):
         """What type and how many dice to use for re-gaining hit points.
-
+        
         To change, set hit_dice_num and hit_dice_faces."""
-        return " + ".join([f"{c.level}d{c.hit_dice_faces}" for c in self.class_list])
+        dice_s = " + ".join([f"{c.level}d{c.hit_dice_faces}" for c in self.class_list])
+        dice_s = combine_dice(dice_s)
+        return dice_s
 
     @property
     def hit_dice_faces(self):
