@@ -139,6 +139,39 @@ class Scout(SubClass):
     features_by_level[17] = [features.SuddenStrike]
 
 
+class Soulknife(SubClass):
+    """Most assassins strike with physical weapons, and many burglars and
+    spies use thieves' tools to infiltrate secure locations. In
+    contrast, a Soulknife strikes and infiltrates with the mind,
+    cutting through barriers both physical and psychic. These rogues
+    discover psionic power within themselves and channel it to do
+    their roguish work. They find easy employment as members of
+    thieves' guilds, though they are often mistrusted by rogues who
+    are leery of anyone using strange mind powers to conduct their
+    business. Most governments would also be happy to employ a
+    Soulknife as a spy.
+
+    Amid the trees of ancient forests on the Material Plane and in the
+    Feywild, some wood elves walk the path of the Soulknife, serving
+    as silent, lethal guardians of their woods. In the endless war
+    among the gith, a githzerai is encouraged to become a Soulknife
+    when stealth is required against the githyanki foe.
+
+    As a Soulknife, your psionic abilities might have haunted you
+    since you were a child, only revealing their full potential as you
+    experienced the stress of adventure. Or you might have sought out
+    a reclusive order of psychic adepts and spent years learning how
+    to manifest your power.
+
+    """
+    name = "Soulknife"
+    features_by_level = defaultdict(list)
+    features_by_level[3] = [features.PsionicPower, features.PsychicBlades]
+    features_by_level[9] = [features.SoulBlades]
+    features_by_level[13] = [features.PsychicVeil]
+    features_by_level[17] = [features.RendMind]
+
+
 class Swashbuckler(SubClass):
     """You focus your training on the art of the blade, relying on speed,
     elegance, and charm in equal parts. While some warriors are brutes clad in
@@ -216,6 +249,7 @@ class Rogue(CharClass):
         Inquisitive,
         Mastermind,
         Scout,
+        Soulknife,
         Swashbuckler,
     )
 
