@@ -72,11 +72,15 @@ def create_latex_pdf(
     module_root = Path(__file__).parent / "modules/"
     module_dirs = [module_root / mdir for mdir in ["DND-5e-LaTeX-Template"]]
     log.debug(f"Loading additional modules from {module_dirs}.")
-    environment['TEXINPUTS'] = f".:{':'.join(str(d) for d in module_dirs)}:" + tex_env
+    texinputs = f".:{':'.join(str(d) for d in module_dirs)}:{module_root}:{tex_env}"
+    environment['TEXINPUTS'] = texinputs
     passes = 2 if use_dnd_decorations else 1
     log.debug(tex_command_line)
     log.debug("LaTeX command: %s" % " ".join(tex_command_line))
-    log.debug("LaTeX environ: %s" % environment)
+    log.debug("LaTeX TEXINPUTS: %s" % texinputs)
+    log.debug("LaTeX environ:")
+    for key, val in environment.items():
+        log.debug("    %s: %s" % (key, val))
     try:
         for i in range(passes):
             result = subprocess.run(
@@ -99,6 +103,8 @@ def create_latex_pdf(
                 for line in tex_error_msg.split("\n"):
                     log.error(line)
             raise exceptions.LatexError(err_msg)
+    finally:
+        environment['TEXINPUTS'] = tex_env
 
 
 def tex_error(logfile: Path) -> str:
@@ -167,7 +173,7 @@ def latex_parts(
     return parts
 
 
-def rst_to_latex(rst, top_heading_level=0):
+def rst_to_latex(rst, top_heading_level: int=0, format_dice: bool = True, use_dnd_decorations=False):
     """Basic markup of reST to LaTeX code.
 
     The translation between reST headings and LaTeX headings is
@@ -184,7 +190,10 @@ def rst_to_latex(rst, top_heading_level=0):
     top_heading_level : optional
       The highest level heading that will be added to the LaTeX as
       described above.
-
+    format_dice
+      If true, dice strings (e.g. "1d4") will be formatted in
+      monospace font.
+    
     Returns
     =======
     tex : str
@@ -196,7 +205,13 @@ def rst_to_latex(rst, top_heading_level=0):
         tex = ""
     else:
         # Mark hit dice in monospace font
-        rst = dice_re.sub(r"``\1``", rst)
+        if format_dice:
+            rst = dice_re.sub(r"``\1``", rst)
         tex_parts = latex_parts(rst)
         tex = tex_parts["body"]
+    # Apply fancy D&D decorations
+    if use_dnd_decorations:
+        tex = re.sub(r"p{[0-9.]+\\DUtablewidth}", "l ", tex, flags=re.M)
+        tex = tex.replace(r"\begin{supertabular}[c]", r"\begin{DndTable}")
+        tex = tex.replace(r"\end{supertabular}", r"\end{DndTable}")
     return tex
